<?php
/**
 * Plugin Name: Enquir3 Case Studies
 * Plugin URI: https://www.enquir3.com/wordpress-case-studies-plugin
 * Description: Case Studies using the Enquir3 System.
 * Author: Enquir3 Ltd.
 * Author URI: https://www.enquir3.com
 * Version: 1.0.2
 */

define( 'EQ3CS_PLUGIN_PATH', dirname( __FILE__ ) . '/' );
define( 'EQ3CS_PLUGIN_BASENAME', basename( __FILE__ ) );

require_once EQ3CS_PLUGIN_PATH . 'includes/enquir3-casestudies-midcopy.inc';
require_once EQ3CS_PLUGIN_PATH . 'widgets/latest-casestudy.inc';


$eq3cs_feedback_options = get_option(
	'enquir3_feedback_options_new',
	array( 'client_id' => '' )
);
$eq3cs_case_studies     = new EQ3CS_Case_Studies( $eq3cs_feedback_options );

/**
 * Class: EQ3CS_Case_Studies
 */
class EQ3CS_Case_Studies {

	/**
	 * Instance of feedback client.
	 *
	 * @var RemstoCaseStudyClient $casestudy_client Remsto Client
	 */
	protected $casestudy_client;

	/**
	 * Client ID.
	 *
	 * @var int $site_id
	 */
	protected $site_id;

	/**
	 * Constructor
	 *
	 * @param type $conf Configration.
	 */
	public function __construct( $conf ) {

		$this->client_conf = $conf;
		$this->site_id     = $conf['client_id'];
		if ( '' !== $this->site_id ) {
			add_shortcode(
				'enquir3-casestudy-tabs',
				array( $this, 'enquir3_casestudies_tabs' )
			);
			add_shortcode(
				'enquir3-casestudy-midcopy-published',
				array( $this, 'enquir3_casestudies_midcopy_published' )
			);
			add_shortcode(
				'enquir3-casestudy-midcopy-promoted',
				array( $this, 'enquir3_casestudies_midcopy_promoted' )
			);
			add_shortcode(
				'enquir3-casestudy-article',
				array( $this, 'enquir3_casestudies_article' )
			);
			add_action( 'wp_enqueue_scripts', array( $this, 'casestudies_js' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'casestudies_js' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'casestudies_css' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'casestudies_css' ) );
			add_action( 'widgets_init', array( $this, 'casestudies_create_widgets' ) );
			add_action( 'admin_post_casestudy_form_submit', array( $this, 'casestudy_form_submit' ) );
			add_action(
				'admin_post_casestudy_delete_form_submit',
				array( $this, 'casestudy_delete_form_submit' )
			);
		}
		add_action( 'admin_menu', array( $this, 'add_menu_items' ) );
		add_action( 'plugins_loaded', array( $this, 'init' ) );
	}

	/**
	 * Activate
	 */
	public static function activate() {
		if ( ! is_plugin_active( 'enquir3-feedback/enquir3-feedback.php' ) ) {
			// Deactivate the plugin.
			deactivate_plugins( basename( __FILE__ ) );
			// Throw an error in the WordPress admin console.
			$error_message = __( 'This plugin requires the Enquir3 Feedback to be active!' );
			die( esc_attr( $error_message ) );
		}

		// Create required pages.
		self::create_tabs_page();
		self::create_article_page();

		// Add capabilities.
		self::add_capability();
	}

	/**
	 * Deactivate
	 */
	public static function deactivate() {
		// Remove capabilities.
		self::remove_capability();
	}

	/**
	 * Initialise plug-in
	 */
	public function init() {

		include_once EQ3F_PLUGIN_PATH . 'vendor/enquir3/RemstoForm.inc';
		include_once EQ3CS_PLUGIN_PATH . 'vendor/enquir3/RemstoItem.inc';
		include_once EQ3F_PLUGIN_PATH . 'vendor/enquir3/RemstoClient.inc';
		include_once EQ3CS_PLUGIN_PATH . 'vendor/enquir3/RemstoCasestudyClient.inc';
		include_once EQ3CS_PLUGIN_PATH . 'vendor/enquir3/RemstoCaseStudyForms.inc';
		include_once EQ3CS_PLUGIN_PATH . 'vendor/enquir3/RemstoCaseStudyItem.inc';
		include_once EQ3CS_PLUGIN_PATH . 'includes/class-eq3cs-case-studies-management-table.php';
		include_once EQ3F_PLUGIN_PATH . 'vendor/enquir3/RemstoModuleFunctions.inc';

		$this->casestudy_client = new RemstoCaseStudyClient( $this->client_conf );
	}

	/**
	 * Register JavaScript files
	 *
	 * @return void
	 */
	public function casestudies_js() {
		wp_register_script(
			'eq3cs-tabs-script',
			plugins_url( '/js/casestudy_tabs.js', __FILE__ ),
			array( 'jquery' ),
			'1.0',
			true
		);
		wp_register_script(
			'eq3cs-ajax-client-script',
			plugins_url( '/js/remsto_ajax_client.js', __FILE__ ),
			array( 'jquery' ),
			'1.0',
			true
		);
		wp_register_script(
			'jquery-jcarousel',
			plugins_url( '/js/jquery.jcarousel.js', __FILE__ ),
			array( 'jquery' ),
			'1.0',
			true
		);
		wp_register_script(
			'eq3cs-casestudies-scroller',
			plugins_url( '/js/casestudies_scroller.js', __FILE__ ),
			array( 'jquery' ),
			'1.0',
			true
		);
	}

	/**
	 * Register style sheet files
	 *
	 * @return void
	 */
	public function casestudies_css() {
		wp_register_style(
			'eq3cs-item-style',
			plugins_url( '/css/casestudy-item.css', __FILE__ ),
			array(),
			'1.0'
		);
		wp_register_style(
			'eq3cs-casestudy',
			plugins_url( '/css/remsto_casestudy.css', __FILE__ ),
			array(),
			'1.0'
		);
		wp_register_style(
			'eq3cs-casestudy-recent-widget',
			plugins_url( '/css/remsto-casestudy-recent-widget.css', __FILE__ ),
			array(),
			'1.0'
		);
		wp_register_style(
			'eq3cs-midcopy',
			plugins_url( '/css/remsto_casestudy_mid_copy.css', __FILE__ ),
			array(),
			'1.0'
		);
	}

	/**
	 * Register widgets
	 */
	public function casestudies_create_widgets() {
		register_widget( 'eq3cs_latest_casestudies_widget' );
	}

	/**
	 * Process Ajax requests
	 */
	public function remsto_casestudy_ajax() {
		include_once CASESTUDY_PLUGIN_PATH . 'includes/RemstoCasestudyAjax.inc';
		$casestudy_ajax = new RemstoCasestudyAjax( $this->casestudy_client );
		$output         = $casestudy_ajax->getData();
		echo esc_html( $output );
		wp_die();
	}

	/**
	 * Create Tabs Page
	 *
	 * @return void
	 */
	private static function create_tabs_page() {

		$test = get_page_by_title( 'Case Studies' );

		if ( $test ) {
			if ( 'trash' !== $test->post_status ) {
				return;
			}
		}

		$new_page = array(
			'post_type'    => 'page',
			'post_title'   => 'Case Studies',
			'post_content' => '[enquir3-casestudy-tabs]',
			'post_status'  => 'publish',
			'post_author'  => 1,
			'post_slug'    => 'case-studies',
		);

		return wp_insert_post( $new_page );

	}

	/**
	 * Create case study page
	 *
	 * @return void
	 */
	private static function create_article_page() {

		$test = get_page_by_title( 'Case Study Article' );

		if ( $test ) {
			if ( 'trash' !== $test->post_status ) {
				return;
			}
		}

		$new_page = array(
			'post_type'    => 'page',
			'post_title'   => 'Case Study Article',
			'post_content' => '[enquir3-casestudy-article]',
			'post_status'  => 'publish',
			'post_author'  => 1,
			'post_slug'    => 'case-studies-article',
		);

		return wp_insert_post( $new_page );

	}

	/**
	 * List case studies in tab display
	 *
	 * @return string
	 */
	public function enquir3_casestudies_tabs() {

		wp_enqueue_script( 'eq3cs-ajax-client-script' );
		wp_enqueue_script( 'eq3cs-tabs-script' );
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-dialog' );
		wp_enqueue_script( 'eq3f-video-dialog' );
		wp_enqueue_style( 'eq3f-base-style' );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		wp_enqueue_style( 'eq3f-item-style' );
		wp_enqueue_style( 'eq3f-icon-style' );
		wp_enqueue_style( 'eq3f-rating-widget' );
		wp_enqueue_style( 'eq3cs-item-style' );

		wp_localize_script( 'eq3cs-ajax-client-script', 'remsto_ajax_settings', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

		$tab = filter_input( INPUT_GET, 'tab' );
		if ( ! $tab ) {
			$tab = 0; // promoted tab.
		}
		wp_localize_script( 'eq3cs-tabs-script', 'tabs_settings', array( 'tab' => $tab ) );

		$output = "<div class='remtso-tabs-container clearfix'><ul class='remtso-tabs'>";

		$output .= "<li data-page='page_promoted' class='tab-selected remtso-tab'>Our outstanding case studies</li>";
		$output .= "<li data-page='page_feedback' class='remtso-tab'>More great case studies</li></ul>";
		$output .= "<div class='clearfix'></div>";

		$output .= "<div id='page_promoted'>";
		$output .= "<div id='promoted_data'>";

		$p0 = filter_input( INPUT_GET, 'p0' );
		if ( ! $p0 ) {
			$p0 = 0;
		}
		// Present the feedback data.
		$output .= $this->remsto_casestudy_display_items( 2, $p0, 0 );
		$output .= '</div></div>';

		$output .= "<div id='page_feedback'>";
		$output .= "<div id='published_dataa'>";
		$p1      = filter_input( INPUT_GET, 'p1' );
		if ( ! $p1 ) {
			$p1 = 0;
		}
		$output .= $this->remsto_casestudy_display_items( '1,2', $p1, 1 );
		$output .= '</div></div>';

		return $output;
	}

	/**
	 * Mid copy short code process
	 *
	 * @param  array $atts Attributes.
	 * @return string
	 */
	public function enquir3_casestudies_midcopy_published( $atts ) {

		$eq3cs_feedback_options = get_option( 'enquir3_feedback_options_new', array() );

		$atts = shortcode_atts(
			array(
				'title'          => null,
				'comment_label'  => $eq3cs_feedback_options['reply_label'],
				'max_char'       => 100,
				'term_id'        => null,
				'max_char_reply' => 100,
				'seq'            => null,
				'published'      => array( 1, 2 ),
			),
			$atts
		);

		wp_enqueue_style( 'eq3cs-midcopy' );

		return eq3cs_display_mid_copy( $atts );
	}


	/**
	 * Mid copy short code process
	 *
	 * @param  array $atts Attributes.
	 * @return string
	 */
	public function enquir3_casestudies_midcopy_promoted( $atts ) {

		$eq3cs_feedback_options = get_option( 'enquir3_feedback_options_new', array() );

		$atts = shortcode_atts(
			array(
				'title'          => null,
				'comment_label'  => $eq3cs_feedback_options['reply_label'],
				'max_char'       => 100,
				'term_id'        => null,
				'max_char_reply' => 100,
				'seq'            => null,
				'published'      => array( 2 ),
			),
			$atts
		);

		wp_enqueue_style( 'eq3cs-midcopy' );

		return eq3cs_display_mid_copy( $atts );
	}

	/**
	 * Get list of case studies
	 *
	 * @param  int $status published/promoted.
	 * @param  int $page_number Page number.
	 * @param  int $tab Tab number.
	 * @return string
	 */
	public function remsto_casestudy_display_items( $status, $page_number = 0, $tab = 0 ) {

		$client_options = get_option( 'enquir3_feedback_options_new', array() );

		$pager               = array(
			'items_per_page' => 10,
			'page_number'    => $page_number,
		);
		$filter['published'] = $status;

		$casestudy_data = $this->casestudy_client->listCasestudies(
			$client_options['listing_id'],
			$filter,
			$pager
		);

		$output                                      = '';
		$display_options                             = array();
		$display_options['display_stood_out_length'] = 150;
		$display_options['display_company_comment_length'] = 100;

		if ( $casestudy_data ) {
			// Present the casestudy data.
			foreach ( $casestudy_data['case_studies'] as $casestudy ) {
				$cs                        = new RemstoCaseStudyItem( $casestudy->data );
				$display_data              = $cs->formatForDisplay( $display_options );
				$display_data['edit_link'] = admin_url( 'admin.php?page=casestudy-management&cid=' . $cs->id );
				$output                   .= EQ3F_Feedback::compile_template(
					EQ3CS_PLUGIN_PATH . 'views/casestudy-item.tpl.php',
					$display_data
				);
			}

			// Render pager links.
			if ( $page_number > 0 ) {
				$current_page = $page_number - 1;
			} else {
				$current_page = 0;
			}

			$output .= $this->case_study_pager( $casestudy_data['total_results'], $page_number, $tab );
		}

		return $output;
	}

	/**
	 *
	 * Get pager
	 *
	 * @param int  $total Total number of items.
	 * @param int  $current_page Current page.
	 * @param type $tab Current tan number.
	 * @return string
	 */
	private function case_study_pager( $total, $current_page, $tab ) {

		$pages = ceil( $total / 10 );

		// Don't show pager if only one page exits.
		if ( $pages < 2 ) {
			return '';
		}

		$pager    = "<div class='nav-pager'><ul>";
		$page_url = get_page_link();

		for ( $x = 1; $x <= $pages; $x++ ) {
			$page = $x - 1;
			if ( $page === $current_page ) {
				$current = 'current_page';
			} else {
				$current = '';
			}
			$pager .= "<li class='nav-pager-item $current' data-page='$page'>";
			$pager .= "<a title='Go to page $x' href='$page_url?tab=$tab&amp;p$tab=$page'>$x</a>";
			$pager .= '</li>';
		}

		$pager .= '</ul></div>';

		return $pager;
	}

	/**
	 * Display case study entry form
	 *
	 * @param  array $atts Attributes.
	 * @return string
	 */
	public function remsto_casestudy_entry_form( $atts ) {

		wp_enqueue_script( 'eq3f-tinymce' );
		wp_enqueue_script( 'eq3f-video-dialog' );
		wp_enqueue_style( 'eq3cs-casestudy' );

		$case_study = new RemstoCaseStudyItem();
		$entryform  = new RemstoCaseStudyEditForm( $this->casestudy_client, $case_study );
		return $entryform->display();
	}


	/**
	 * Add menu pages
	 */
	public function add_menu_items() {
		add_menu_page(
			'Enquir3 Case Studies',
			'Enquir3 Case Studies',
			'enquir3_casestudy_moderate',
			'casestudy-management',
			array( $this, 'remsto_casestudy_management_render_page' ),
			'dashicons-media-document'
		);
	}

	/**
	 * Process add case study form
	 */
	public function casestudy_form_submit() {

		try {

			$op = filter_input( INPUT_POST, 'op' );

			switch ( $op ) {
				case 'Save':
					$this->save_casestudy();
					$redirect_path = admin_url( 'admin.php?page=casestudy-management' );
					break;
				case 'Remove Icon':
					$cid = filter_input( INPUT_POST, 'id' );
					$this->remove_icon( $cid );
					$redirect_path = admin_url( "admin.php?page=casestudy-management&action=edit&cid=$cid" );
					break;
				case 'Cancel':
					$redirect_path = admin_url( 'admin.php?page=casestudy-management' );
					break;
			}

			wp_safe_redirect( $redirect_path );
			exit();

		} catch ( Exception $ex ) {
			echo '<div class="notice notice-error is-dismissible">';
			echo '<p>' . esc_attr( $ex->getMessage() ) . '</p></div>';
		}
	}


	/**
	 * Save new/changed case study.
	 */
	private function save_casestudy() {

		$anonymous = filter_input( INPUT_POST, 'anonymous' );
		if ( null === $anonymous ) {
			$_POST['anonymous'] = '0';
		} else {
			$_POST['anonymous'] = '1';
		}

		$eq3cs_feedback_options = get_option( 'enquir3_feedback_options_new', array( 'client_id' => '' ) );
		$this_site_status       = filter_input( INPUT_POST, 'this_site_status' );
		if ( ! $this_site_status ) {
			if ( $eq3cs_feedback_options['auto_publish'] ) {
				$this_site_status = 1; // published.
			} else {
				$this_site_status = 0; // unpublished.
			}
		}

		$site_status = array(
			array(
				'site_id' => $this->site_id,
				'status'  => $this_site_status,
			),
		);

		$image_files = array();

		if ( isset( $_FILES['customer_logo_image'] ) && ! empty( $_FILES['customer_logo_image']['name'] ) ) {
			$image_files['customer_logo_image'] = array(
				'name'  => ! empty( $_FILES['customer_logo_image']['name'] ) ? esc_url_raw( wp_unslash( $_FILES['customer_logo_image']['name'] ) ) : '',
				'field' => 'customer_logo_image',
				'file'  => ! empty( $_FILES['customer_logo_image']['tmp_name'] ) ? esc_url_raw( wp_unslash( $_FILES['customer_logo_image']['tmp_name'] ) ) : '',
			);
			$_POST['customer_logo_src']         = esc_url_raw( wp_unslash( $_FILES['customer_logo_image']['name'] ) );
		}

		$case_study_item            = RemstoCaseStudyItem::fromPost( $site_status );
		$post_data                  = $case_study_item->toArray();
		$post_data['_upload_files'] = $image_files;
		$tid                        = $this->casestudy_client->addCasestudy( $post_data );
	}

	/**
	 * Remove icon from specified case study
	 *
	 * @param type $cid Case study ID.
	 */
	private function remove_icon( $cid ) {
		$this->casestudy_client->deleteImage( $cid, 'customer_logo_src' );
	}

	/**
	 * Delete case study
	 */
	public function casestudy_delete_form_submit() {

		try {

			$op = filter_input( INPUT_POST, 'op' );

			if ( 'Yes' === $op ) {
				$cid = filter_input( INPUT_POST, 'cid' );
				$this->casestudy_client->deleteCasestudyItem( $cid );
			}

			wp_safe_redirect( admin_url( 'admin.php?page=casestudy-management' ) );
			exit();
		} catch ( Exception $ex ) {
			print esc_attr( $ex->getMessage() );
		}
	}

	/**
	 * Display complete case study.
	 *
	 * @param  array $attr Attributes.
	 * @return string
	 */
	public function enquir3_casestudies_article( $attr ) {

		$cid = filter_input( INPUT_GET, 'cid' );

		if ( ! $cid ) {
			return 'Case study not found';
		}

		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-dialog' );
		wp_enqueue_script( 'eq3f-video-dialog' );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		wp_enqueue_style( 'eq3f-item-style' );
		wp_enqueue_style( 'eq3f-icon-style' );
		wp_enqueue_style( 'eq3f-rating-widget' );
		wp_enqueue_style( 'eq3f-base-style' );
		wp_enqueue_style( 'eq3cs-casestudy' );
		wp_enqueue_style( 'eq3cs-item-style' );

		$display_options = shortcode_atts(
			array(
				'display_stood_out_length'       => 150,
				'display_company_comment_length' => 100,
			),
			$attr
		);

		$case_study = $this->casestudy_client->getCasestudyById( $cid );

		$case_study_data = $case_study->formatForDisplay( $display_options );
		return EQ3F_Feedback::compile_template(
			EQ3CS_PLUGIN_PATH . 'views/casestudy-article.tpl.php',
			$case_study_data
		);
	}

	/**
	 * Handle case study management page
	 */
	public function remsto_casestudy_management_render_page() {

		if ( ! current_user_can( 'enquir3_casestudy_moderate' ) ) {
			wp_die( 'Not Authorised' );
		}

		$action = filter_input( INPUT_GET, 'action' );

		switch ( $action ) {
			case 'edit':
				$this->remsto_casestudy_management_edit();
				break;
			case 'delete':
				$this->remsto_casestudy_management_delete();
				break;
			default:
				$this->remsto_casestudy_management_table();
		}
	}

	/**
	 * Display case study management table
	 */
	public function remsto_casestudy_management_table() {

		$test_list_table = new EQ3CS_Case_Studies_Management_Table( $this->casestudy_client );
		// Fetch, prepare, sort, and filter our data...
		$test_list_table->prepare_items();
		?>
			<div class="wrap">

				<div id="icon-users" class="icon32"><br/></div>
				<h2>Case Study Management</h2>

				<!-- Forms are NOT created automatically, so you need to wrap the table in one to use features like bulk actions -->
				<form id="casestudy-filter" method="get">
					<input type="hidden" name="page" value="<?php echo filter_input( INPUT_GET, 'page' ); ?>" />
		<?php $test_list_table->display(); ?>
				</form>

			</div>
		<?php
	}

	/**
	 * Add/edit case study
	 */
	public function remsto_casestudy_management_edit() {

		wp_enqueue_script( 'eq3f-tinymce' );
		wp_enqueue_script( 'eq3f-forms' );
		wp_enqueue_style( 'eq3cs-casestudy' );

		$cid = filter_input( INPUT_GET, 'cid' );
		$fid = filter_input( INPUT_GET, 'fid' );
		if ( $cid ) {
			$case_study = $this->casestudy_client->getCasestudyById( $cid );
		} elseif ( $fid ) {
			$feedback_client = new RemstoFeedbackClient( $this->client_conf );
			$feedback        = $feedback_client->getFeedbackItem( 0, 0, $fid );
			$case_study_data = array(
				'feedback_details'     => $feedback->stood_out,
				'company_comment'      => $feedback->company_comment,
				'feedback_id'          => $feedback->id,
				'rating_promised'      => $feedback->rating_promised,
				'rating_value'         => $feedback->rating_value,
				'rating_helpful'       => $feedback->rating_helpful,
				'rating_communication' => $feedback->rating_communication,
				'anonymous'            => $feedback->anonymous,
				'first_name'           => $feedback->first_name,
				'last_name'            => $feedback->last_name,
				'email'                => $feedback->email,
				'town'                 => $feedback->town,
				'county'               => $feedback->county,
				'telephone'            => $feedback->telephone,
				'company_name'         => $feedback->company_name,
				'sector'               => $feedback->business_category,
				'position'             => $feedback->position,
				'website'              => $feedback->website,
			);
			$case_study      = new RemstoCaseStudyItem( $case_study_data );
		} else {
			$case_study = new RemstoCaseStudyItem();
		}

		$entryform = new RemstoCaseStudyEditForm( $this->casestudy_client, $case_study );
		?>
			<div class="wrap">
				<div id="icon-users" class="icon32"><br/></div>
				<h2>Case Study Management</h2>
		<?php
		$allowed_html = array(
			'form'     => array(
				'action'  => array(),
				'enctype' => array(),
				'method'  => array(),
			),
			'input'    => array(
				'id'        => array(),
				'class'     => array(),
				'type'      => array(),
				'name'      => array(),
				'value'     => array(),
				'size'      => array(),
				'maxlength' => array(),
				'checked'   => array(),
			),
			'label'    => array(
				'for' => array(),
			),
			'div'      => array(
				'class' => array(),
			),
			'span'     => array(
				'class' => array(),
				'title' => array(),
			),
			'textarea' => array(
				'id'          => array(),
				'name'        => array(),
				'class'       => array(),
				'rows'        => array(),
				'cols'        => array(),
				'placeholder' => array(),
			),
			'img'      => array(
				'src' => array(),
			),
			'h2'       => array(),
		);
		echo wp_kses( $entryform->display(), $allowed_html );
		?>
			</div>
		<?php
	}

	/**
	 * Case study delete
	 */
	public function remsto_casestudy_management_delete() {

		$cid            = filter_input( INPUT_GET, 'cid' );
		$casestudy_item = $this->casestudy_client->getCasestudyById( $cid );
		$msg            = $cid . ' ' . $casestudy_item->title;
		$hidden         = array(
			array(
				'name'  => 'cid',
				'value' => $cid,
			),
		);
		$settings       = array(
			'link'    => esc_url( admin_url( 'admin-post.php' ) ),
			'action'  => 'casestudy_delete_form_submit',
			'hidden'  => $hidden,
			'message' => "Are you sure you wish to delete case study <br> $msg ?",
		);
		return EQ3F_Feedback::render_template(
			EQ3CS_PLUGIN_PATH . 'views/casestudy-confirmation-form.tpl.php',
			$settings
		);
	}


	/**
	 * Add moderate capability
	 */
	public static function add_capability() {
		$role = get_role( 'administrator' );
		$role->add_cap( 'enquir3_casestudy_moderate' );
	}

	/**
	 * Remove moderate capability
	 */
	public static function remove_capability() {
		$role = get_role( 'administrator' );
		$role->remove_cap( 'enquir3_casestudy_moderate' );
	}

}

register_activation_hook( __FILE__, array( 'EQ3CS_Case_Studies', 'activate' ) );
register_deactivation_hook( __FILE__, array( 'EQ3CS_Case_Studies', 'deactivate' ) );
