<?php
/**
 * Code for managing case studies
 */

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * Class for listing case studies
 */
class EQ3CS_Case_Studies_Management_Table extends WP_List_Table {

	/**
	 * Instance of feedback client.
	 *
	 * @var RemstoCaseStudyClient $casestudy_client Remsto Client
	 */
	protected $casestudy_client;

	/**   * ***********************************************************************
	 * REQUIRED. Set up a constructor that references the parent constructor. We
	 * use the parent reference to set some default config.
	 * ************************************************************************* */
	/**
	 * Constructor
	 *
	 * @param type $casestudy_client Feedback client.
	 */
	public function __construct( $casestudy_client ) {
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		wp_enqueue_style( 'eq3f-rating-widget' );
		wp_enqueue_style( 'eq3f-item-style' );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-dialog' );
		wp_enqueue_script( 'eq3f-more-popup-script' );
		wp_enqueue_script( 'eq3f-feedback-ajax-client-script' );
		wp_localize_script(
			'eq3f-feedback-ajax-client-script',
			'remsto_ajax_settings',
			array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
		);

		// Set parent defaults.
		parent::__construct(
			array(
				'singular' => 'casestudy', // singular name of the listed records.
				'plural'   => 'casestudy', // plural name of the listed records.
				'ajax'     => false,        // does this table support ajax?
			)
		);
		$this->casestudy_client = $casestudy_client;
	}

	/**
	 * Defaults for columns
	 *
	 * @param array $item All columns.
	 * @param str   $column_name Name of column.
	 *
	 * @return string Data to display
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'id':
			case 'title':
			case 'client':
			case 'rating':
			case 'status':
			case 'created':
			case 'last_modified':
			case 'view':
				return $item[ $column_name ];
			default:
				return 'Error occurred';
		}
	}

	/**
	 * Add row actions
	 *
	 * @param array $item Columns array.
	 *
	 * @return type
	 */
	public function column_title( $item ) {

		$page = filter_input( INPUT_GET, 'page' );

		$edit_link   = admin_url( 'admin.php?page=casestudy-management&action=edit&cid=' . $item['id'] );
		$delete_link = admin_url( 'admin.php?page=casestudy-management&action=delete&cid=' . $item['id'] );
		// http://wordpress.localhost/wp-admin/admin.php?page=casestudy-manage&cid=110
		// Build row actions.
		$actions = array(
			'edit'   => "<a href='$edit_link'>Edit</a>",
			'delete' => "<a href='$delete_link'>Delete</a>",
		);

		// Return the title contents.
		return $item['title'] . $this->row_actions( $actions );
	}

	/**
	 * Checkbox columns
	 *
	 * @param array $item Columns.
	 *
	 * @return str
	 */
	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			/* $1%s */ $this->_args['singular'],
			/* $2%s */ $item['id']
		);
	}

	/**
	 * Get columns
	 *
	 * @return str
	 */
	public function get_columns() {
		$columns = array(
			'id'            => '#',
			'title'         => 'Title',
			'client'        => 'Client',
			'rating'        => 'Rating',
			'status'        => 'Status',
			'created'       => 'Created',
			'last_modified' => 'Last Modified',
			'view'          => 'View',
		);
		return $columns;
	}

	/**
	 * Prepare rows
	 */
	public function prepare_items() {

		require_once EQ3F_PLUGIN_PATH . 'vendor/enquir3/RemstoModuleFunctions.inc';
		require_once EQ3F_PLUGIN_PATH . 'vendor/enquir3/RemstoClientSiteStatus.inc';

		$items_per_page = 10;
		wp_enqueue_script( 'eq3f-more-popup-script' );

		// Get current page number for this page.
		$page_number = $this->get_pagenum() - 1;

		// Column headings.
		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = array();

		$this->_column_headers = array( $columns, $hidden, $sortable );

		// Get the casestudy data.
		$feedback_options = get_option( 'enquir3_feedback_options_new', array() );
		if ( isset( $feedback_options['service_taxonomy'] ) ) {
			$service_taxonomy = $feedback_options['service_taxonomy'];
		} else {
			$service_taxonomy = null;
		}

		$filter           = array(
			'site_id'     => $feedback_options['client_id'],
			'parent_type' => 0,
			'parent_id'   => 0,
			'taxonomy_id' => $service_taxonomy,
			'deleted'     => 0,
		);
		$filter_published = filter_input( INPUT_GET, 'filter-published' );
		if ( strlen( $filter_published ) > 0 && 'all' !== $filter_published ) {
			if ( '1' === $filter_published ) {
				$status = '1,2';
			} else {
				$status = $filter_published;
			}
		} else {
			$status = '0,1,2';
		}

		$sort = array(
			'order' => 'created',
			'sort'  => 'DESC',
		);

		$pager               = array(
			'items_per_page' => $items_per_page,
			'page_number'    => $page_number,
		);
		$filter['published'] = $status;

		$casestudy_data = $this->casestudy_client->listCasestudies(
			$feedback_options['listing_id'],
			$filter,
			$pager
		);

		$rows = array();
		foreach ( $casestudy_data['case_studies'] as $casestudy ) {

			$cs = new RemstoCaseStudyItem( $casestudy->data, $casestudy->site_status );

			$status = $cs->site_status[0]->status;

			$rows[] = array(
				'id'            => $cs->id,
				'title'         => $cs->title,
				'client'        => $cs->company_name,
				'rating'        => '',
				'status'        => RemstoClientSiteStatus::toText( $status ),
				'created'       => gmdate( 'd-m-Y H:i:s', $cs->created_date ),
				'last_modified' => gmdate( 'd-m-Y H:i:s', $cs->changed_date ),
				'view'          => '',
			);
		}
		/**
		 * REQUIRED. Now we can add our *sorted* data to the items property, where
		 * it can be used by the rest of the class.
		 */
		$this->items = $rows;

		// Set up the pager.
		$this->set_pagination_args(
			array(
				'total_items' => $casestudy_data['total_results'],
				'per_page'    => $items_per_page,
				'total_pages' => ceil( $casestudy_data['total_results'] / $items_per_page ),
			)
		);
	}

	/**
	 * Extra table navigation
	 *
	 * @param type $which Top.
	 */
	public function extra_tablenav( $which ) {
		$published_options = array(
			0 => 'Unpublished',
			1 => 'Published',
			2 => 'Promoted',
		);
		if ( 'top' === $which ) {
			// Add a filter for 'published'.
			$add_link = admin_url( 'admin.php?page=casestudy-management&action=edit' );
			print "<a href='" . esc_url( $add_link ) . "'>Add Case Study</a><br>";
			$filter_published = filter_input( INPUT_GET, 'filter-published' );
			print '<div class="alignleft actions bulkactions">';
			print '<select name="filter-published" class="filter-published">';
			print '<option value="">-- Filter by Published --</option>';
			foreach ( $published_options as $option_id => $option_title ) {
				$selected = '';
				if ( !empty( $filter_published ) && intval( $filter_published ) === $option_id ) {
					$selected = ' selected = "selected"';
				}
				print '<option value="' . esc_attr( $option_id ) . '"' . esc_attr( $selected ) . '>' . esc_attr( $option_title ) . '</option>';
			}
			print '</select>';

			submit_button( 'Filter', 'secondary', false, false );
			print '</div>';
		}
	}

}
