<?php
/**
 * Code for displaying mid copy case studies
 */

/**
 * Display mid copy case studies
 *
 * @param array $instance A case study.
 * @return string HTML markup
 */
function eq3cs_display_mid_copy( $instance ) {

	$client_options = get_option( 'enquir3_feedback_options_new', array() );
	$rc             = new RemstoCaseStudyClient( $client_options );

	$pager = array(
		'items_per_page' => 1,
		'page_number'    => 0,
	);

	$sort = array(
		'order' => 'published_date',
		'sort'  => 'DESC',
	);

	$filter = array(
		'published' => implode( ',', $instance['published'] ),
		'randomise' => true,
	);

	if ( isset( $instance['term_id'] ) ) {
		$filter['service'] = array( $instance['term_id'] );
	}

	$casestudy_data = $rc->listCasestudies( $client_options['listing_id'], $filter, $pager, $sort );

	if ( count( $casestudy_data['case_studies'] ) === 0 ) {
		return '';
	}

	foreach ( $casestudy_data['case_studies'] as $casestudy ) {
		$case_study = new RemstoCaseStudyItem( $casestudy->data );
	}

	$len = $instance['max_char'];
	if ( $len > 0 ) {
		$summary_description = RemstoModuleFunctions::truncate_utf8(
			sanitize_textarea_field( $case_study->summary_description ),
			$len,
			true,
			true
		);
	} else {
		$summary_description = sanitize_textarea_field( $case_study->summary_description );
	}

	$len_comment = $instance['max_char_reply'];
	if ( $len_comment > 0 && '' !== $case_study->company_comment ) {
		$company_comment = RemstoModuleFunctions::truncate_utf8(
			esc_html( $case_study->company_comment ),
			$len_comment,
			true,
			true
		);
	} else {
		$company_comment = RemstoModuleFunctions::check_plain( $case_study->company_comment );
	}

	$feedback_data = array(
		'text'                  => $summary_description,
		'more_link'             => $case_study->fullPageLink(),
		'listing_link'          => '',
		'company_name'          => sanitize_text_field( $case_study->company_name ),
		'date'                  => gmdate( 'd/m/Y', $case_study->published_date ),
		'title'                 => $instance['title'],
		'company_comment'       => $company_comment,
		'company_comment_label' => $instance['comment_label'],
	);

	$name = array(
		'anon'       => $case_study->anonymous,
		'first_name' => sanitize_text_field( $case_study->first_name ),
		'last_name'  => sanitize_text_field( $case_study->last_name ),
	);

	if ( $case_study->anonymous ) {
		$feedback_data['first_name'] = 'Client details withheld';
		$feedback_data['last_name']  = '';
		$feedback_data['town']       = '';
	} else {
		$feedback_data['first_name'] = esc_html( $case_study->first_name );
		$feedback_data['last_name']  = esc_html( $case_study->last_name );
		$feedback_data['town']       = esc_html( $case_study->town );
	}

	$feedback_data['author'] = $case_study->formatNameDisplay( $name );

	return EQ3F_Feedback::compile_template(
		EQ3CS_PLUGIN_PATH . 'includes/views/casestudy-mid-copy.tpl.php',
		$feedback_data
	);
}
