<?php

class RemstoCaseStudyEditForm extends RemstoForm {

  protected $tid;

  /**
   * @var RemstoCaseStudyClient $casestudy_client Remsto Case Study Client
   */
  protected $casestudy_client;

  /**
   * @var RemstoCaseStudyItem $case_study Case Study Item
   */
  protected $case_study;

  public function __construct($casestudy_client, $case_study) {

    $this->tid = null;
    $this->feedback_client = $casestudy_client;
    $this->case_study = $case_study;
  }

  public function display() {
    
    if ($this->tid) {
      $taxonomy = $this->feedback_client->getTaxonomy($this->tid);
    }
    else {
      $taxonomy = new stdClass();
      $taxonomy->title = '';
    }

    $form = '';

    $form_settings['title'] = array(
      'name' => 'title',
      'label' => 'Title',
      'type' => 'text',
      'value' => $this->case_study->title,
    );


    $form_settings['description'] = array(
      'name' => 'description',
      'label' => 'Description',
      'type' => 'textarea',
      'rows' => 10,
      'value' => $this->case_study->description,
      'title' => 'A brief explanation of the case study saying someone did something for someone else which produced an outcome',  
    );


    $form_settings['feedback_details'] = array(
      'name' => 'feedback_details',
      'label' => 'Feedback Details',
      'type' => 'textarea',
      'maxlength' => 2048,
      'value' => $this->case_study->feedback_details
    );


    $form_settings['company_comment'] = array(
      'name' => 'company_comment',
      'type' => 'textarea',
      'maxlength' => 2048,
      'label' => 'Company Reply',
      'value' => $this->case_study->company_comment
    );


    $form_settings['video_testimonial'] = array(
      'name' => 'video_testimonial',
      'label' => 'Video Testimonial',
      'type' => 'text',
      'value' => $this->case_study->video_testimonial,
    );

    $form_settings['markup1'] = array(
      'markup' => '<h2>Personal Details</h2>',
      'type' => 'markup',
    );
    
    $form_settings['anonymous'] = array(
      'name' => 'anonymous',
      'label' => 'Anonymous?',
      'type' => 'checkbox',
      'value' => $this->case_study->anonymous,
    );

    $form_settings['first_name'] = array(
      'name' => 'first_name',
      'label' => 'First Name',
      'type' => 'text',
      'value' => $this->case_study->first_name,
    );

    $form_settings['last_name'] = array(
      'name' => 'last_name',
      'label' => 'Last Name',
      'type' => 'text',
      'value' => $this->case_study->last_name,
    );
    
    $form_settings['email'] = array(
      'name' => 'email',
      'label' => 'Email',
      'type' => 'text',
      'value' => $this->case_study->email,
    );

    $form_settings['town'] = array(
      'name' => 'town',
      'label' => 'Town',
      'type' => 'text',
      'value' => $this->case_study->town,
    );

    $form_settings['county'] = array(
      'name' => 'county',
      'label' => 'County',
      'type' => 'text',
      'value' => $this->case_study->county,
    );

    $form_settings['telephone'] = array(
      'name' => 'telephone',
      'label' => 'Telephone',
      'type' => 'text',
      'value' => $this->case_study->telephone,
    );

    $form_settings['company_name'] = array(
      'name' => 'company_name',
      'label' => 'Company Name',
      'type' => 'text',
      'value' => $this->case_study->company_name,
    );

    $form_settings['sector'] = array(
      'name' => 'sector',
      'label' => 'Sector',
      'type' => 'text',
      'value' => $this->case_study->sector,
    );

    $form_settings['position'] = array(
      'name' => 'position',
      'label' => 'Position',
      'type' => 'text',
      'value' => $this->case_study->position,
    );

    $form_settings['website'] = array(
      'name' => 'website',
      'label' => 'Website',
      'type' => 'text',
      'value' => $this->case_study->website,
    );
    
    if ($this->case_study->customer_logo_src == '') {
      $form_settings['customer_logo'] = array(
        'name' => 'customer_logo_image',
        'label' => 'Customer Logo',
        'type' => 'file',
        'description' => 'Upload an image, allowed extensions: jpg, jpeg, png, gif',
      );
    }
    else {
      $remstoItemHelper = new remstoItemHelper(null);
      $customer_image = $remstoItemHelper->formatImage(
          array(
            'src' => $this->case_study->customer_logo_src,
            'alt' => $this->case_study->customer_logo_alt,
            'class' => 'tpp-field-logo'
          )
      );
      $form_settings['customer_logo'] = array(
        'markup' => $customer_image,
        'type' => 'markup',
      );
      
      // Remove icon button
      $form_settings['icon_remove_button'] = array(
      'markup' => '<input id="edit-submit" name="op" value="Remove Icon" class="form-submit" type="submit">',
      'type' => 'markup',
    );
      
    }


    $form_settings['customer_logo_alt'] = array(
      'name' => 'customer_logo_alt',
      'label' => 'Customer Alt Text',
      'type' => 'text',
      'value' => $this->case_study->customer_logo_alt
    );

    // Descriptions

    $form_settings['markup2'] = array(
      'markup' => '<h2>Descriptions</h2>',
      'type' => 'markup',
    );

    $form_settings['about_title'] = array(
      'name' => 'about_title',
      'label' => 'About Title',
      'type' => 'text',
      'value' => $this->case_study->about_title,
      'title' => 'A line including company name and type of company'
    );

    $form_settings['about_description'] = array(
      'name' => 'about_description',
      'type' => 'textarea',
      'label' => 'About Description',
      'value' => $this->case_study->about_description,
      'title' => 'An explanation of what the company giving the testimonial does, essentially like an about us section on a website'  
    );

    $form_settings['problem_title'] = array(
      'name' => 'problem_title',
      'label' => 'Problem Title',
      'type' => 'text',
      'value' => $this->case_study->problem_title,
      'title' => 'A line summarising the main problem',
    );

    $form_settings['problem_description'] = array(
      'name' => 'problem_description',
      'type' => 'textarea',
      'label' => 'Problem Description',
      'value' => $this->case_study->problem_description,
      'title' => 'An explanation of the problem that led to the need for help and why they went to the company they did'
    );

    $form_settings['solution_title'] = array(
      'name' => 'solution_title',
      'label' => 'Solution Title',
      'type' => 'text',
      'value' => $this->case_study->solution_title,
      'title' => 'A line summarising the main solution',
    );

    $form_settings['solution_description'] = array(
      'name' => 'solution_description',
      'type' => 'textarea',
      'label' => 'Solution Description',
      'value' => $this->case_study->solution_description,
      'title' => 'An explanation of the solution to the problem and how it made a difference',
    );


    $form_settings['services_title'] = array(
      'name' => 'services_title',
      'label' => 'Services Title',
      'type' => 'text',
      'value' => $this->case_study->services_title,
      'title' => 'Simply what services were provided?',
    );

    $form_settings['services_description'] = array(
      'name' => 'services_description',
      'type' => 'textarea',
      'label' => 'Services Description',
      'value' => $this->case_study->services_description,
      'title' => 'A bullet point list of the services that were provided',
    );

    $form_settings['recommendation_title'] = array(
      'name' => 'recommendation_title',
      'label' => 'Recomendation Title',
      'type' => 'text',
      'value' => $this->case_study->recommendation_title,
      'title' => 'Simply what would you say to someone looking to use this company’s services?',
    );

    $form_settings['recommendation_description'] = array(
      'name' => 'recommendation_description',
      'type' => 'textarea',
      'label' => 'Recomendation Description',
      'value' => $this->case_study->recommendation_description,
      'title' => 'A positive quote as to why they would recommend',
    );

    $form_settings['summary_title'] = array(
      'name' => 'summary_title',
      'label' => 'Summary Title',
      'type' => 'text',
      'value' => $this->case_study->summary_title,
      'title' => 'A line saying what the case study is about including both company names',
    );

    $form_settings['summary_description'] = array(
      'name' => 'summary_description',
      'type' => 'textarea',
      'label' => 'Summary Description',
      'value' => $this->case_study->summary_description,
      'title' => 'A brief summary of what the case study is about, no more than 120 characters',
    );

    
    $action = esc_url(admin_url('admin-post.php'));
    $id = $this->case_study->id;
    $tid = $this->case_study->feedback_id;
    $nonce = wp_create_nonce('remsto_casestudy_edit');

    $form .= "<form action='$action' enctype='multipart/form-data' method='post' id='casestudy-form' >";
    $form .= '<input type="hidden" name="action" value="casestudy_form_submit">';
    $form .= "<input type='hidden' name='id' value='$id'>";
    $form .= "<input type='hidden' name='tid' value='$tid'>";
    $form .= "<input type='hidden' name='fid' value='$tid'>";
    $form .= "<input type='hidden' name='_wpnonce' value='$nonce'>";

    // TODO get valuse from settings (listing id)
    $form .= "<input type='hidden' name='parent_type' value='1'>";
    $client_options = get_option('enquir3_feedback_options_new', array());
    $listing_id = $client_options['listing_id'];
    $form .= "<input type='hidden' name='parent_id' value='$listing_id'>";


    foreach ($form_settings as $element => $settings) {

      switch ($settings['type']) {
        case 'text':
          $form .= $this->addFormTextInput($settings);
          break;
        case 'textarea':
          $form .= $this->addFormTextArea($settings);
          break;
        case 'checkbox':
          $form .= $this->addFormCheckBoxInput($settings);
          break;
        case 'markup':
          $form .= $this->addFormMarkup($settings['markup']);
          break;
        case 'file':
          $form .= $this->addFileUpload($settings);
          break;
      }
    }
    
    //customer_logo_image
    $test = array(
      'name' => 'customer_logo_image',
      'label' => 'Customer Logo',
      'description' => 'Upload an image, allowed extensions: jpg, jpeg, png, gif',
    );
    
        //customer_logo_image

    $test2 = array(
      'name' => 'other_logo_image',
      'label' => 'Other Logo',
      'description' => 'For testing',
    );
    
    //$form .= $this->addFileUpload($test);
    
    //$form .= $this->addFileUpload($test2);
    
    //$client_options = get_option('enquir3_feedback_options_new', array());
    $site_status = $this->case_study->site_status;
    $this_site_status = 1;
    if ($site_status) {
      foreach ($site_status as $site) {
        if ($site->site_id == $client_options['client_id']) {
          $this_site_status = $site->status;
          break;
        }
      }
    }


    $form .= $this->addItemStatusSelect($this_site_status);

    $form .= '<input id="edit-submit" name="op" value="Save" class="form-submit" type="submit">';
    $form .= '<input id="edit-cancel" name="op" value="Cancel" class="form-submit" type="submit">';
    $form .= '</form>';

    return $form;
  }

}
