<?php

/**
 * Description of RemstoCaseStudy
 *
 * @author Ian Burnup
 * 
 * @property String $id case study id
 * @property String $title case study title
 * @property string $description case study description
 * @property string $feedback_details feedback stood out testimonial detail
 * @property string $company_comment feedback company comment
 * @property string $about_title Should contain a title for about section
 * @property String $about_description Should contain a the about section detail
 * @property String $problem_title Title for the problem section
 * @property String $problem_description Details for the problem section
 * @property String $solution_title Title for the solution section
 * @property String $solution_description Details for the solution section
 * @property String $services_title Title for the service section
 * @property String $services_description Details for the service section
 * @property String $recommendation_title Title for the recommendation section
 * @property String $recommendation_description Details for the recommendation section
 * @property String $summary_title Summary Title
 * @property String $summary_description Summary Description
 * @property String $video_testimonial Video Testimonial
 * 
 * @property String $first_name First Name
 * @property String $last_name Last Name
 * @property String $email Email address
 * @property String $town Town
 * @property String $county County
 * @property String $telephone Telephone Number
 * @property String $company_name Company Name
 * @property String $sector Company sector
 * @property String $position Position
 * @property String $website Web site Address
 * @property int $anonymous Anonymous 0/1
 * @property int $feedback_id ID of related feedback
 * @property Array $site_status Site Status
 * @property Array $taxonomies Item Taxonomy
 * @property String $customer_logo_src Customer logo
 * @property String $customer_logo_alt Customer Logo alt text
 * 
 * @property String $published_date Published Date
 */
class RemstoCaseStudyItem extends RemstoItem {

  protected $id;
  protected $feedback_id = 0;
  protected $title, $description, $feedback_details, $company_comment, $about_title;
  protected $about_description, $problem_title, $problem_description;
  protected $solution_title, $solution_description, $services_title, $services_description;
  protected $recommendation_title, $recommendation_description;
  protected $path_alias = '';
  protected $video_testimonial;
  protected $anonymous = 0;
  protected $first_name, $last_name, $email, $town, $county, $telephone;
  protected $company_name, $sector, $position, $website;
  protected $customer_logo_src, $customer_logo_alt;
  protected $rating_promised = 100;
  protected $rating_value = 100;
  protected $rating_helpful = 100;
  protected $rating_communication = 100;
  protected $summary_title, $summary_description, $summary_logo_src, $summary_logo_alt;
  protected $meta_description, $meta_keywords;
  protected $published_date, $created_date, $changed_date, $deleted_date;
  protected $listing_company_name, $listing_website;
  protected $site_status;
  protected $taxonomies;

  /**
   * @property Object $feedback
   *  Partial feedback data.
   */
  protected $feedback;

  public function __construct($case_study_data = null, $site_status = null, $taxonomies = null) {
    
    parent::__construct($case_study_data);
    
    $this->site_status = $site_status;
    $this->taxonomies = $taxonomies;

    if (isset($case_study_data->feedback)) {
      $this->feedback = $case_study_data->feedback;
      $this->rating_promised = $this->feedback->rating_promised;
      $this->rating_communication = $this->feedback->communication;
      $this->rating_helpful = $this->feedback->rating_helpful;
      $this->rating_value = $this->feedback->rating_value;
    }

    if (isset($case_study_data->listing)) {
      $this->listing_company_name = $case_study_data->listing->company_name;
      $this->listing_website = $case_study_data->listing->website;
      $this->listing_path = '';
    }
  }

  public function __get($name) {

    if (property_exists($this, $name)) {
      return $this->$name;
    }
  }

  public function toArray() {

    $data = array(
      'id' => $this->id,
      'feedback_id' => $this->feedback_id,
      'parent_type' => $this->parent_type,
      'parent_id' => $this->parent_id,
      'title' => $this->title,
      'description' => $this->description,
      'feedback_details' => $this->feedback_details,
      'company_comment' => $this->company_comment,
      'video_testimonial' => $this->video_testimonial,
      'about_title' => $this->about_title,
      'about_description' => $this->about_description,
      'problem_title' => $this->problem_title,
      'problem_description' => $this->problem_description,
      'solution_title' => $this->solution_title,
      'solution_description' => $this->solution_description,
      'services_title' => $this->services_title,
      'services_description' => $this->services_description,
      'recommendation_title' => $this->recommendation_title,
      'recommendation_description' => $this->recommendation_description,
      // Customer Details
      'anonymous' => $this->anonymous,
      'first_name' => $this->first_name,
      'last_name' => $this->last_name,
      'email' => $this->email,
      'town' => $this->town,
      'county' => $this->county,
      'telephone' => $this->telephone,
      'company_name' => $this->company_name,
      'sector' => $this->sector,
      'position' => $this->position,
      'website' => $this->website,
      'customer_logo_src' => $this->customer_logo_src,
      'customer_logo_alt' => $this->customer_logo_alt,
      // Summary Details (i.e. Side Bar)
      'summary_title' => $this->summary_title,
      'summary_description' => $this->summary_description,
      'summary_logo_src' => $this->summary_logo_src,
      'summary_logo_alt' => $this->summary_logo_alt,
      'meta_description' => $this->meta_keywords,
      'meta_keywords' => $this->meta_keywords,
      'path_alias' => $this->path_alias,
      'published_date' => $this->published_date,
      'created_date' => $this->created_date,
      'changed_date' => $this->changed_date,
      'deleted_date' => $this->deleted_date,
      'site_status' => $this->site_status,
    );

    return $data;
  }

  /**
   * Format case study data to be displayed.
   * @param type $options
   * @return string
   */
  public function formatForDisplay($options) {

    $formated_data = $this->toArray();
    
    $formated_data['feedback_details'] = $this->formatTextValue(
        array(
          'truncate' => $options['display_stood_out_length'],
          'label' => '',
          'value' => $this->feedback_details,
          'class' => 'tpp-field-feedback-details'
    ));

    $formated_data['company_comment'] = $this->formatTextValue(
        array(
          'truncate' => $options['display_company_comment_length'],
          'label' => 'Company Comment:',
          'value' => $this->company_comment,
          'class' => 'tpp-field-company-comment'
    ));

    $formated_data['website'] = $this->formatWebsite($this->website);

    $summary_rating = $this->calculateRating();
    if ($summary_rating === FALSE) {
      $formated_data['rating_summary'] = 'n/a';
    }
    else {
      $formated_data['rating_summary'] = $this->formatRatingStars(
          array(
            'rating' => $summary_rating,
            'label' => '',
            'stars' => 5
          )
      );
    }

    $formated_data['title'] = $this->formatTextValue(
        array(
          'truncate' => $options['display_company_comment_length'],
          'label' => '',
          'value' => $this->title,
          'class' => 'tpp-field-title'
    ));

    $formated_data['date'] = $this->formatTextValue(
        array(
          'label' => 'Date:',
          'value' => date('d/m/Y', $this->published_date),
          'class' => 'tpp-field-date'
        )
    );

    $name = array(
      'anon' => $this->anonymous,
      'first_name' => $this->first_name,
      'last_name' => $this->last_name,
      'town' => '',
    );

    $author = $this->formatNameDisplay($name);
    
    $formated_data['author'] = $this->formatTextValue(
        array(
          'label' => 'Name:',
          'value' => $author,
          'class' => 'tpp-field-author'
        )
    );
   
    $formated_data['position'] = $this->formatTextValue(
        array(
          'label' => 'Job Title:',
          'value' => $this->position,
          'class' => 'tpp-field-possition'
    ));
    
    $formated_data['town'] = $this->formatTextValue(
        array(
          'label' => 'Town:',
          'value' => $this->town,
          'class' => 'tpp-field-town'
    ));
    
    $formated_data['sector'] = $this->formatTextValue(
        array(
          'label' => 'Sector:',
          'value' => $this->sector,
          'class' => 'tpp-field-sector'
    ));
        
    $client = $this->formatClientDisplay(array(
      'anon' => $this->anonymous,
      'company_name' => $this->company_name,
      'website' => $this->website,
    ));

    $formated_data['client'] = $this->formatTextValue(
        array(
          'label' => 'Supplier:',
          'value' => $client,
          'class' => 'tpp-field-client'
        )
    );

    if ($this->listing_company_name) {
      $supplier = $this->formatClientDisplay(array(
        'anon' => 0,
        'company_name' => $this->listing_company_name,
        'website' => $this->listing_website,
      ));

      $formated_data['supplier'] = $this->formatTextValue(
          array(
            'label' => 'Supplier:',
            'value' => $supplier,
            'class' => 'tpp-field-supplier'
          )
      );
    }
    
    // Customer logo
    if ($this->customer_logo_src) {
      $formated_data['customer_logo'] = $this->formatImage(
          array(
            'src' => $this->customer_logo_src,
            'alt' => $this->customer_logo_alt,
            'class' => 'tpp-field-supplier',
          )
      );
    }



    $formated_data['company_name_section'] = $this->formatTextValue(
        array(
          'label' => 'Client:',
          'value' => $this->company_name,
          'class' => 'tpp-field-company-name'
    ));
    
    $formated_data['company_name'] = $this->company_name;

    $formated_data['telephone'] = $this->formatTextValue(
        array(
          'label' => 'Tel:',
          'value' => $this->telephone,
          'class' => 'tpp-field-company-telephone'
    ));

    $formated_data['website_link'] = $this->formatWebsite($this->website, FALSE);
    
    $formated_data['website_section'] = "<div class='tpp-field tpp-field-company-website' title='company website'>";
    $formated_data['website_section'] .= "<span class='tpp-label'>Web:</span>";     
    $formated_data['website_section'] .= "<span class='tpp-value'>" . $formated_data['website_link'] . "</span></div>";
    
    $formated_data['email'] = $this->formatTextValue(
        array(
          'label' => 'Email:',
          'value' => $this->email,
          'class' => 'tpp-field-company-email'
    ));

    if (!empty($this->video_testimonial)) {     
      $formated_data['video_testimonial'] = 
          RemstoModuleFunctions::processVideoTestimonial($this->id, $this->video_testimonial); 
    }
    
    $formated_data['about_section'] = $this->formatSection($this->about_title, $this->about_description);
    $formated_data['problem_section'] = $this->formatSection($this->problem_title, $this->problem_description);
    $formated_data['solution_section'] = $this->formatSection($this->solution_title, $this->solution_description);
    $formated_data['services_section'] = $this->formatSection($this->services_title, $this->services_description);
    $formated_data['recommendation_section'] = $this->formatSection($this->recommendation_title, $this->recommendation_description);


    $formated_data['created_date'] = date('d/m/Y', $this->created_date);
    $formated_data['created_time'] = date('h:i', $this->created_date);
    
    $formated_data['more_button'] = $this->fullPageLink();
    
    if (current_user_can('enquir3_casestudy_moderate')) {
      $formated_data['action_buttons'] = $this->caseStudyActions($this->id);
    }
    
    return $formated_data;
  }

  /**
   * calculate overall rating
   * @param type $feedback
   * @return boolean
   */
  private function calculateRating() {

    $promised = $this->rating_promised;
    $value = $this->rating_value;
    $helpful = $this->rating_helpful;
    $communication = $this->rating_communication;

    $count = 0;
    $rating = 0;

    if ($promised > 0) {
      $rating += $promised;
      $count++;
    }

    if ($value > 0) {
      $rating += $value;
      $count++;
    }

    if ($helpful > 0) {
      $rating += $helpful;
      $count++;
    }

    if ($communication > 0) {
      $rating += $communication;
      $count++;
    }

    if ($count > 0) {
      return round($rating / $count);
    }

    return FALSE;
  }

  /**
   * Format case study section for display.
   * @param type $title
   * @param type $descrption
   * @return string
   */
  private function formatSection($title, $descrption) {

    if (!empty($descrption)) {
      $output = '<section class="row row-about-description">';
      $output .= '<div class="title item-about-title">';
      $output .= sanitize_text_field($title);
      $output .= '</div>';

      $output .= '<div class="item-about-description">';
      $output .= sanitize_textarea_field($descrption);
      $output .= '</div></section>';
    }
    else {
      $output = '';
    }

    return $output;
  }
  
  private function caseStudyActions($id) {

    $edit_link = admin_url("admin.php?page=casestudy-management&action=edit&cid=$id");
    $delete_link = admin_url("admin.php?page=casestudy-management&action=delete&cid=$id"); 
    $output = "<a class='btn btn-edit remsto-btn' href='$edit_link' data-id='{{id}}'>Edit</a>";
    $output .= "<a class='btn btn-delete remsto-btn' href='$delete_link' data-id='{{id}}'>Delete</a>";
    //$output .= "<a class='btn btn-delete' href='/remsto-client-case-study/{{id}}/delete' data-id='$id'>Delete</a>";        
        
    return $output;    
  }
  
  private function videoButton() {
    return "<div class='btn btn-show-video-toggle remsto-btn' data-id='$this->id'>View Video</div>";
  }
  
  /**
   * Get markup for case study link to full page
   * @return type
   */
  public function fullPageLink() {
    return "<a class='btn btn-view remsto-btn' href='case-study-article?cid=$this->id' data-id='$this->id'>Read More</a>";
  }
  
  /**
   * Create new case study item from $_POST super global
   * @param array $site_status site status
   */
  public static function fromPost($site_status) {
    
    $data = array();
    
    $data['id'] = filter_input(INPUT_POST, 'id');
    $data['feedback_id'] = filter_input(INPUT_POST, 'fid');
    $data['parent_type'] = filter_input(INPUT_POST, 'parent_type');
    $data['parent_id'] = filter_input(INPUT_POST, 'parent_id');
    $data['title'] = filter_input(INPUT_POST, 'title');
    $data['description'] = filter_input(INPUT_POST, 'description');
    $data['feedback_details'] = filter_input(INPUT_POST, 'feedback_details');
    $data['company_comment'] = filter_input(INPUT_POST, 'company_comment');
    $data['video_testimonial'] = filter_input(INPUT_POST, 'video_testimonial');
    $data['about_title'] = filter_input(INPUT_POST, 'about_title');
    $data['about_description'] = filter_input(INPUT_POST, 'about_description');
    $data['problem_title'] = filter_input(INPUT_POST, 'problem_title');
    $data['problem_description'] = filter_input(INPUT_POST, 'problem_description');
    $data['solution_title'] = filter_input(INPUT_POST, 'solution_title');   
    $data['solution_description'] = filter_input(INPUT_POST, 'solution_description');
    $data['services_title'] = filter_input(INPUT_POST, 'services_title');
    $data['services_description'] = filter_input(INPUT_POST, 'services_description');
    $data['recommendation_title'] = filter_input(INPUT_POST, 'recommendation_title');
    $data['recommendation_description'] = filter_input(INPUT_POST, 'recommendation_description');
    // Customer Details
    $data['anonymous'] = filter_input(INPUT_POST, 'anonymous');   
    $data['first_name'] = filter_input(INPUT_POST, 'first_name');
    $data['last_name'] = filter_input(INPUT_POST, 'last_name');
    $data['email'] = filter_input(INPUT_POST, 'email');
    $data['town'] = filter_input(INPUT_POST, 'town');
    $data['county'] = filter_input(INPUT_POST, 'county');  
    $data['telephone'] = filter_input(INPUT_POST, 'telephone');
    $data['company_name'] = filter_input(INPUT_POST, 'company_name');
    $data['sector'] = filter_input(INPUT_POST, 'sector');
    $data['position'] = filter_input(INPUT_POST, 'position');
    $data['website'] = filter_input(INPUT_POST, 'website');   
    $data['customer_logo_src'] = filter_input(INPUT_POST, 'customer_logo_src');
    $data['customer_logo_alt'] = filter_input(INPUT_POST, 'customer_logo_alt');
    // Summary Details (i.e. Side Bar)
    $data['summary_title'] = filter_input(INPUT_POST, 'summary_title');
    $data['summary_description'] = filter_input(INPUT_POST, 'summary_description');
    $data['summary_logo_src'] = filter_input(INPUT_POST, 'summary_logo_src');
    $data['summary_logo_alt'] = filter_input(INPUT_POST, 'summary_logo_alt');
    $data['meta_description'] = filter_input(INPUT_POST, 'meta_description');
    $data['meta_keywords'] = filter_input(INPUT_POST, 'meta_keywords');
    $data['path_alias'] = filter_input(INPUT_POST, 'path_alias');   
    $data['published_date'] = filter_input(INPUT_POST, 'published_date');
    $data['created_date'] = filter_input(INPUT_POST, 'created_date');
    $data['changed_date'] = filter_input(INPUT_POST, 'changed_date');
    $data['deleted_date'] = filter_input(INPUT_POST, 'deleted_date');

    return new RemstoCaseStudyItem($data, $site_status);
    
  }

}
