<?php

/**
 * 
 * Remote Case Study Backend API calls
 * 
 * Calls to backend
 * 
 * @category   Remsto
 * @package    Irun
 * @author     Ian Burnup
 * @copyright  Irun 2016
 */
class RemstoCaseStudyClient extends RemstoClient {

  /**
   * List case studies
   * @param Array $filter Filter settings
   * @param Array $pager Pager settings
   * @param Array $sort Sort settings
   * @return Array case study data
   */
  public function listCasestudies($listing_id, $filter = array(), $pager = array(), $sort = array()) {
    $options = array();
    $options['filter'] = $filter + array(
      '_site_id' => $this->config['client_id'],
      'listing_id' => $listing_id,
    );

    $options['pager'] = $pager + array(
      'items_per_page' => 10,
      'page_number' => 0,
    );

    $options['sort'] = $sort + array(
      'order' => 'published_date',
      'sort' => 'DESC',
    );

    $list_data = array('case_studies' => array(), 'total_results' => NULL);

    try {
      $data = $this->sendData('/api/v1/case-study/list', $options);

      if (!empty($data->case_studies)) {
        foreach ($data->case_studies as $case_data) {
          //$case_study = RemstoClientCaseStudy::init($case_data);

          $list_data['case_studies'][] = $case_data;
        }
      }

      if (!empty($data->total_results)) {
        $list_data['total_results'] = $data->total_results;
      }
    }
    catch (Exception $ex) {
      $this->displayException($ex);
    }

    return $list_data;
  }

  /**
   * Add/Edit Case study
   * @param Array $case_study details
   * @return type
   */
  public function addCasestudy($case_study) {

    if (isset($case_study['site_status'])) {
      $site_status = $case_study['site_status'];
    }
    else {
      $site_status = array();

      $site_status[] = array(
        'site_id' => $this->config['client_id'],
        'status' => 1,
      );
    }

    $post_data = array(
      'case_study' => $case_study,
      'site_status' => $site_status,
      'taxonomies' => array(),
    );


    if (!empty($case_study['_upload_files'])) {
      $post_data['_upload_files'] = $case_study['_upload_files'];
    }

    $rtn = null;

    try {
      $response = $this->sendData('/api/v1/case-study/update', $post_data);

      if (isset($response->case_study->id)) {
        $id = $response->case_study->id;
      }

      $rtn = $response->update_status;

      /*
        if (isset($response->case_study->path_alias)) {
        $this->data['path_alias'] = $response->case_study->path_alias;
        }
       */
    }
    catch (Exception $ex) {
      throw $ex;
    }

    return $rtn;
  }
  
  
  /**
   * Delete case study item.
   * @param int $cid Case study ID
   * @return boolean
   */
  public function deleteCasestudyItem($cid) {

    try {
      $response = $this->sendData("/api/v1/case-study/delete/$cid");
      if (!empty($response->delete_status)) {
        return TRUE;
      }
    }
    catch (Exception $ex) {
      $this->displayException($ex);
    }

    return FALSE;
  }

  /**
   * Get case study by id
   * @param int $id ID of case study
   * @return \RemstoCaseStudyItem
   */
  public function getCasestudyById($id) {

    try {
      $data = $this->sendData("/api/v1/case-study/get/$id");
      $site_status = $data->case_study->site_status;
      $taxonomies = $data->case_study->taxonomies;
      $case_study = new RemstoCaseStudyItem($data->case_study->data, $site_status, $taxonomies);
    }
    catch (Exception $ex) {
      $case_study = new RemstoCaseStudyItem();
      //$this->displayException($ex);
    }

    return $case_study;
  }
  
  /**
   * Get case study by feedback id
   * @param type $feedback_id
   * @return \RemstoCaseStudyItem
   */
  public function getByFeedbackId($feedback_id) {

    try {
      $data = $this->sendData("/api/v1/case-study/get-by-feedback/$feedback_id");

      if (!empty($data->case_study)) {
        $case_study = new RemstoCaseStudyItem($data->case_study->data);
      }
      else {
        $case_study = new RemstoCaseStudyItem();  
      }
    }
    catch (Exception $e) {
      $case_study = new RemstoCaseStudyItem();
    }

    return $case_study;
  }

  /**
   * Remove image form case study
   * @param type $field
   * @return type
   * @throws Exception
   */
  public function deleteImage($id, $field_name) {

    $post_data = array(
      'case_study_id' => $id,
      'image_field' => $field_name,
    );

    try {
      $response = $this->sendData('/api/v1/case-study/delete-image', $post_data);
      $rtn = $response->update_status;
    }
    catch (Exception $ex) {
      $rtn = '';
      $msg = $ex->getMessage();
      //print "<div class='notice notice-error is-dismissible'><p>$msg</div></p>";  
      $this->displayException($ex);
    }

    return $rtn;
  }

}

// end of class

